@@ -15,6 +15,7 @@ use base qw( App::Codit::BaseClasses::TextModPlugin );
 use Data::Compare;
 use Tk;
 require Tk::HList;
+require Tk::FileBrowser::Header;
 
 =head1 DESCRIPTION
 
@@ -39,6 +40,8 @@ sub new {
 	my $page = $self->ToolNavigPageAdd('PerlSubs', 'code-context', undef, 'Find your Perl subs');
 
 	$self->{CURRENT} = [];
+	$self->{SORTON} = 'Line';
+	$self->{SORTORDER} = 'ascending';
 	
 	my $hlist = $page->Scrolled('HList',
 		-browsecmd => ['Select', $self],
@@ -49,15 +52,20 @@ sub new {
 	$self->{HLIST} = $hlist;
 	my $count = 0;
 	for ('Sub', 'Line') {
-		my $header = $hlist->Frame;
-		$header->Label(-text => $_)->pack(-side => 'left');
+		my $header = $hlist->Header(
+			-column => $count,
+			-sortcall => ['Sortcall', $self],
+			-text => $_,
+		);
 		$hlist->headerCreate($count,
 			-headerbackground => $self->configGet('-background'),
 			-itemtype => 'window', 
-			-widget => $header);
-#		$list->headerCreate($count, -text => $_);
+			-widget => $header
+		);
 		$count ++;
 	}
+	my $h2 = $hlist->headerCget(1, '-widget');
+	$h2->configure(-sortorder => 'ascending');
 
 	return $self;
 }
@@ -68,11 +76,47 @@ sub Clear {
 	$hlist->deleteAll;
 }
 
+sub Current {
+	my $self = shift;
+	$self->{CURRENT} = shift if @_;
+	return $self->{CURRENT}
+}
+
+sub FillList {
+	my ($self, $new, $select) = @_;
+	$select = 1 unless defined $select;
+	my $hlist = $self->{HLIST};
+	my $cursel;
+	( $cursel ) = $hlist->infoSelection;
+	my $lastvisible = $hlist->nearest($hlist->height - 1);
+	$self->Clear;
+
+	for (@$new) {
+		my ($name, $num) = @$_;
+		my $item = $name;
+		my $count = 2;
+		while ($hlist->infoExists($item)) {
+			$item = "$name$count";
+			$count ++
+		}
+		$hlist->add($item, -data => $num);
+		$hlist->itemCreate($item, 0, -text => $name);
+		$hlist->itemCreate($item, 1, -text => $num);
+	}
+
+	#find and set selection
+	if ($select) {
+		$hlist->selectionSet($cursel) if (defined $cursel) and $hlist->infoExists($cursel);
+		$hlist->see($lastvisible) if (defined $lastvisible) and $hlist->infoExists($lastvisible);
+	}
+	$self->Current($new);
+}
+
 sub Refresh {
 	my ($self, $select) = @_;
 	$self->SUPER::Refresh;
 	$select = 1 unless defined $select;
-	my $current = $self->{CURRENT};
+	my $current = $self->Current;
 	my @new = ();
 
 	my $mdi = $self->extGet('CoditMDI');
@@ -88,36 +132,11 @@ sub Refresh {
 			my $name = $1;
 			push @new, [$name, $num];
 		}
+		@new = $self->Sort(@new);
 	}
 	
 	unless (Compare($current, \@new)) {
-
-		my $hlist = $self->{HLIST};
-		my $cursel;
-		( $cursel ) = $hlist->infoSelection if $hlist->infoSelection;
-	
-		my $lastvisible = $hlist->nearest($hlist->height - 1);
-		$self->Clear;
-
-		for (@new) {
-			my ($name, $num) = @$_;
-			my $item = $name;
-			my $count = 2;
-			while ($hlist->infoExists($item)) {
-				$item = "$name$count";
-				$count ++
-			}
-			$hlist->add($item, -data => $num);
-			$hlist->itemCreate($item, 0, -text => $name);
-			$hlist->itemCreate($item, 1, -text => $num);
-		}
-
-		#find and set selection
-		if ($select) {
-			$hlist->selectionSet($current) if (defined $current) and $hlist->infoExists($current);
-			$hlist->see($lastvisible) if (defined $lastvisible) and $hlist->infoExists($lastvisible);
-		}
-		$self->{CURRENT} = \@new
+		$self->FillList(\@new, $select);
 	}
 }
 
@@ -134,6 +153,60 @@ sub Select {
 	}
 }
 
+sub Sort {
+	my ($self, @list) = @_;
+	my $on = $self->SortOn;
+	my $order = $self->SortOrder;
+	my @new;
+	if ($on eq 'Sub') {
+		if ($order eq 'ascending') {
+			@new = sort {$a->[0] cmp $b->[0]} @list
+		} elsif ($order eq 'descending') {
+			@new = reverse sort {$a->[0] cmp $b->[0]} @list
+		}
+	} elsif ($on eq 'Line') {
+		if ($order eq 'ascending') {
+			@new = sort {$a->[1] <=> $b->[1]} @list
+		} elsif ($order eq 'descending') {
+			@new = reverse sort {$a->[1] <=> $b->[1]} @list
+		}
+	}
+	return @new
+}
+
+sub Sortcall {
+	my ($self, $on, $order) = @_;
+	$self->SortOn($on);
+	$self->SortOrder($order);
+	my $hlist = $self->{HLIST};
+
+	my $col;
+	$col = 0 if $on eq 'Sub';
+	$col = 1 if $on eq 'Line';
+	my $h1 = $hlist->headerCget($col, '-widget');
+	$h1->configure(-sortorder => $order);
+	my $ncol = not $col;
+	my $h2 = $hlist->headerCget($ncol, '-widget');
+	$h2->configure(-sortorder => 'none');
+
+	my $cur = $self->Current;
+	my @new = $self->Sort(@$cur);
+	$self->FillList(\@new);
+	$self->Current(\@new);
+}
+
+sub SortOn {
+	my $self = shift;
+	$self->{SORTON} = shift if @_;
+	return $self->{SORTON}
+}
+
+sub SortOrder {
+	my $self = shift;
+	$self->{SORTORDER} = shift if @_;
+	return $self->{SORTORDER}
+}
+
 sub Unload {
 	my $self = shift;
 	$self->ToolNavigPageRemove('PerlSubs');
